@@ -8,6 +8,7 @@ worker_config_serialize <- function(config) {
     if (isTRUE(config$arrow)) "TRUE" else "FALSE",
     if (isTRUE(config$fetch_result_as_sdf)) "TRUE" else "FALSE",
     if (isTRUE(config$single_binary_column)) "TRUE" else "FALSE",
+    if (isTRUE(config$spark_read)) "TRUE" else "FALSE",
     config$spark_version,
     sep = ";"
   )
@@ -15,7 +16,6 @@ worker_config_serialize <- function(config) {
 
 worker_config_deserialize <- function(raw) {
   parts <- strsplit(raw, ";")[[1]]
-
   list(
     debug = as.logical(parts[[1]]),
     sparklyr.gateway.port = as.integer(parts[[2]]),
@@ -25,6 +25,7 @@ worker_config_deserialize <- function(raw) {
     arrow = as.logical(parts[[6]]),
     fetch_result_as_sdf = as.logical(parts[[7]]),
     single_binary_column = as.logical(parts[[8]]),
-    spark_version = parts[[9]]
+    spark_read = as.logical(parts[[9]]),
+    spark_version = parts[[10]]
   )
 }
