@@ -9,42 +9,60 @@ NULL
 #'
 #' @details
 #'
-#' For `ml_lda.tbl_spark` with the formula interface, you can specify named arguments in `...` that will
-#'   be passed `ft_regex_tokenizer()`, `ft_stop_words_remover()`, and `ft_count_vectorizer()`. For example, to increase the
-#'   default `min_token_length`, you can use `ml_lda(dataset, ~ text, min_token_length = 4)`.
+#' For `ml_lda.tbl_spark` with the formula interface, you can specify named
+#' arguments in `...` that will be passed `ft_regex_tokenizer()`,
+#' `ft_stop_words_remover()`, and `ft_count_vectorizer()`. For example, to
+#' increase the default `min_token_length`, you can use
+#' `ml_lda(dataset, ~ text, min_token_length = 4)`.
 #'
 #' Terminology for LDA:
 #' \itemize{
 #'   \item "term" = "word": an element of the vocabulary
 #'   \item "token": instance of a term appearing in a document
 #'   \item "topic": multinomial distribution over terms representing some concept
-#'   \item "document": one piece of text, corresponding to one row in the input data
+#'   \item "document": one piece of text, corresponding to one row in the input
+#'   data
 #' }
 #'
-#' Original LDA paper (journal version): Blei, Ng, and Jordan. "Latent Dirichlet Allocation." JMLR, 2003.
+#' Original LDA paper (journal version): Blei, Ng, and Jordan. "Latent Dirichlet
+#'  Allocation." JMLR, 2003.
 #'
-#' Input data (\code{features_col}): LDA is given a collection of documents as input data, via the \code{features_col} parameter. Each document is specified as a Vector of length \code{vocab_size}, where each entry is the count for the corresponding term (word) in the document. Feature transformers such as \code{\link{ft_tokenizer}} and \code{\link{ft_count_vectorizer}} can be useful for converting text to word count vectors
+#' Input data (\code{features_col}): LDA is given a collection of documents as
+#' input data, via the \code{features_col} parameter. Each document is specified
+#'  as a Vector of length \code{vocab_size}, where each entry is the count for
+#'  the corresponding term (word) in the document. Feature transformers such as
+#'  \code{\link{ft_tokenizer}} and \code{\link{ft_count_vectorizer}} can be
+#'  useful for converting text to word count vectors
 #'
 #' @section Parameter details:
 #'
 #' \subsection{\code{doc_concentration}}{
-#'   This is the parameter to a Dirichlet distribution, where larger values mean more smoothing (more regularization). If not set by the user, then \code{doc_concentration} is set automatically. If set to singleton vector [alpha], then alpha is replicated to a vector of length k in fitting. Otherwise, the \code{doc_concentration} vector must be length k. (default = automatic)
+#'   This is the parameter to a Dirichlet distribution, where larger values mean
+#'   more smoothing (more regularization). If not set by the user, then
+#'    \code{doc_concentration} is set automatically. If set to singleton vector
+#'     [alpha], then alpha is replicated to a vector of length k in fitting.
+#'      Otherwise, the \code{doc_concentration} vector must be length k.
+#'      (default = automatic)
 #'
 #'   Optimizer-specific parameter settings:
 #'
 #' EM
 #'
 #' \itemize{
-#'   \item Currently only supports symmetric distributions, so all values in the vector should be the same.
+#'   \item Currently only supports symmetric distributions, so all values in
+#'   the vector should be the same.
 #'   \item Values should be greater than 1.0
-#'   \item default = uniformly (50 / k) + 1, where 50/k is common in LDA libraries and +1 follows from Asuncion et al. (2009), who recommend a +1 adjustment for EM.
+#'   \item default = uniformly (50 / k) + 1, where 50/k is common in LDA
+#'   libraries and +1 follows from Asuncion et al. (2009), who recommend a +1
+#'    adjustment for EM.
 #' }
 #'
 #' Online
 #'
 #' \itemize{
 #'   \item Values should be greater than or equal to 0
-#'   \item default = uniformly (1.0 / k), following the implementation from \href{https://github.com/Blei-Lab/onlineldavb}{here}
+#'   \item default = uniformly (1.0 / k), following the implementation from
+#'   \href{https://github.com/Blei-Lab/onlineldavb}{here}
 #'   }
 #' }
 #'
@@ -52,9 +70,12 @@ NULL
 #'
 #' This is the parameter to a symmetric Dirichlet distribution.
 #'
-#' Note: The topics' distributions over terms are called "beta" in the original LDA paper by Blei et al., but are called "phi" in many later papers such as Asuncion et al., 2009.
+#' Note: The topics' distributions over terms are called "beta" in the original
+#' LDA paper by Blei et al., but are called "phi" in many later papers such as
+#' Asuncion et al., 2009.
 #'
-#' If not set by the user, then \code{topic_concentration} is set automatically. (default = automatic)
+#' If not set by the user, then \code{topic_concentration} is set automatically.
+#' (default = automatic)
 #'
 #' Optimizer-specific parameter settings:
 #'
@@ -62,35 +83,63 @@ NULL
 #'
 #' \itemize{
 #'   \item Value should be greater than 1.0
-#'   \item default = 0.1 + 1, where 0.1 gives a small amount of smoothing and +1 follows Asuncion et al. (2009), who recommend a +1 adjustment for EM.
+#'   \item default = 0.1 + 1, where 0.1 gives a small amount of smoothing and +1
+#'   follows Asuncion et al. (2009), who recommend a +1 adjustment for EM.
 #' }
 #'
 #' Online
 #'
 #' \itemize{
 #'   \item Value should be greater than or equal to 0
-#'   \item default = (1.0 / k), following the implementation from \href{https://github.com/Blei-Lab/onlineldavb}{here}.
+#'   \item default = (1.0 / k), following the implementation from
+#'   \href{https://github.com/Blei-Lab/onlineldavb}{here}.
 #'   }
 #' }
 #'
 #' \subsection{\code{topic_distribution_col}}{
-#'   This uses a variational approximation following Hoffman et al. (2010), where the approximate distribution is called "gamma." Technically, this method returns this approximation "gamma" for each document.
+#'   This uses a variational approximation following Hoffman et al. (2010),
+#'   where the approximate distribution is called "gamma." Technically, this
+#'    method returns this approximation "gamma" for each document.
 #' }
 #'
 #'
 #' @template roxlate-ml-clustering-algo
 #' @template roxlate-ml-formula-params
 #' @template roxlate-ml-clustering-params
-#' @param doc_concentration Concentration parameter (commonly named "alpha") for the prior placed on documents' distributions over topics ("theta"). See details.
-#' @param topic_concentration Concentration parameter (commonly named "beta" or "eta") for the prior placed on topics' distributions over terms.
-#' @param topic_distribution_col Output column with estimates of the topic mixture distribution for each document (often called "theta" in the literature). Returns a vector of zeros for an empty document.
+#' @param doc_concentration Concentration parameter (commonly named "alpha")
+#' for the prior placed on documents' distributions over topics ("theta").
+#' See details.
+#' @param topic_concentration Concentration parameter (commonly named "beta" or
+#' "eta") for the prior placed on topics' distributions over terms.
+#' @param topic_distribution_col Output column with estimates of the topic
+#' mixture distribution for each document (often called "theta" in the
+#'  literature). Returns a vector of zeros for an empty document.
 #' @template roxlate-ml-checkpoint-interval
-#' @param optimizer Optimizer or inference algorithm used to estimate the LDA model. Supported: "online" for Online Variational Bayes (default) and "em" for Expectation-Maximization.
-#' @param subsampling_rate (For Online optimizer only) Fraction of the corpus to be sampled and used in each iteration of mini-batch gradient descent, in range (0, 1]. Note that this should be adjusted in synch with \code{max_iter} so the entire corpus is used. Specifically, set both so that maxIterations * miniBatchFraction greater than or equal to 1.
-#' @param learning_decay (For Online optimizer only) Learning rate, set as an exponential decay rate. This should be between (0.5, 1.0] to guarantee asymptotic convergence. This is called "kappa" in the Online LDA paper (Hoffman et al., 2010). Default: 0.51, based on Hoffman et al.
-#' @param learning_offset (For Online optimizer only) A (positive) learning parameter that downweights early iterations. Larger values make early iterations count less. This is called "tau0" in the Online LDA paper (Hoffman et al., 2010) Default: 1024, following Hoffman et al.
-#' @param optimize_doc_concentration (For Online optimizer only) Indicates whether the \code{doc_concentration} (Dirichlet parameter for document-topic distribution) will be optimized during training. Setting this to true will make the model more expressive and fit the training data better. Default: \code{FALSE}
-#' @param keep_last_checkpoint (Spark 2.0.0+) (For EM optimizer only) If using checkpointing, this indicates whether to keep the last checkpoint. If \code{FALSE}, then the checkpoint will be deleted. Deleting the checkpoint can cause failures if a data partition is lost, so set this bit with care. Note that checkpoints will be cleaned up via reference counting, regardless.
+#' @param optimizer Optimizer or inference algorithm used to estimate the LDA
+#' model. Supported: "online" for Online Variational Bayes (default) and "em"
+#' for Expectation-Maximization.
+#' @param subsampling_rate (For Online optimizer only) Fraction of the corpus
+#' to be sampled and used in each iteration of mini-batch gradient descent, in
+#' range (0, 1]. Note that this should be adjusted in synch with \code{max_iter}
+#' so the entire corpus is used. Specifically, set both so that maxIterations *
+#' miniBatchFraction greater than or equal to 1.
+#' @param learning_decay (For Online optimizer only) Learning rate, set as an
+#' exponential decay rate. This should be between (0.5, 1.0] to guarantee
+#' asymptotic convergence. This is called "kappa" in the Online LDA paper
+#' (Hoffman et al., 2010). Default: 0.51, based on Hoffman et al.
+#' @param learning_offset (For Online optimizer only) A (positive) learning
+#' parameter that downweights early iterations. Larger values make early
+#' iterations count less. This is called "tau0" in the Online LDA paper (Hoffman
+#' et al., 2010) Default: 1024, following Hoffman et al.
+#' @param optimize_doc_concentration (For Online optimizer only) Indicates
+#' whether the \code{doc_concentration} (Dirichlet parameter for document-topic
+#' distribution) will be optimized during training. Setting this to true will
+#' make the model more expressive and fit the training data better. Default: \code{FALSE}
+#' @param keep_last_checkpoint (Spark 2.0.0+) (For EM optimizer only) If using
+#' checkpointing, this indicates whether to keep the last checkpoint.
+#' If \code{FALSE}, then the checkpoint will be deleted. Deleting the checkpoint
+#' can cause failures if a data partition is lost, so set this bit with care.
+#' Note that checkpoints will be cleaned up via reference counting, regardless.
 #'
 #' @examples
 #' \dontrun{
@@ -126,21 +175,23 @@ NULL
 #' }
 #'
 #' @export
-ml_lda <- function(x, formula = NULL, k = 10, max_iter = 20, doc_concentration = NULL, topic_concentration = NULL,
-                   subsampling_rate = 0.05, optimizer = "online", checkpoint_interval = 10,
-                   keep_last_checkpoint = TRUE, learning_decay = 0.51, learning_offset = 1024,
-                   optimize_doc_concentration = TRUE, seed = NULL, features_col = "features",
-                   topic_distribution_col = "topicDistribution", uid = random_string("lda_"), ...) {
+ml_lda <- function(
+    x, formula = NULL, k = 10, max_iter = 20, doc_concentration = NULL, topic_concentration = NULL,
+    subsampling_rate = 0.05, optimizer = "online", checkpoint_interval = 10,
+    keep_last_checkpoint = TRUE, learning_decay = 0.51, learning_offset = 1024,
+    optimize_doc_concentration = TRUE, seed = NULL, features_col = "features",
+    topic_distribution_col = "topicDistribution", uid = random_string("lda_"), ...) {
   check_dots_used()
   UseMethod("ml_lda")
 }
 
 #' @export
-ml_lda.spark_connection <- function(x, formula = NULL, k = 10, max_iter = 20, doc_concentration = NULL, topic_concentration = NULL,
-                                    subsampling_rate = 0.05, optimizer = "online", checkpoint_interval = 10,
-                                    keep_last_checkpoint = TRUE, learning_decay = 0.51, learning_offset = 1024,
-                                    optimize_doc_concentration = TRUE, seed = NULL, features_col = "features",
-                                    topic_distribution_col = "topicDistribution", uid = random_string("lda_"), ...) {
+ml_lda.spark_connection <- function(
+    x, formula = NULL, k = 10, max_iter = 20, doc_concentration = NULL, topic_concentration = NULL,
+    subsampling_rate = 0.05, optimizer = "online", checkpoint_interval = 10,
+    keep_last_checkpoint = TRUE, learning_decay = 0.51, learning_offset = 1024,
+    optimize_doc_concentration = TRUE, seed = NULL, features_col = "features",
+    topic_distribution_col = "topicDistribution", uid = random_string("lda_"), ...) {
   .args <- list(
     k = k,
     max_iter = max_iter,
@@ -192,11 +243,12 @@ ml_lda.spark_connection <- function(x, formula = NULL, k = 10, max_iter = 20, do
 }
 
 #' @export
-ml_lda.ml_pipeline <- function(x, formula = NULL, k = 10, max_iter = 20, doc_concentration = NULL, topic_concentration = NULL,
-                               subsampling_rate = 0.05, optimizer = "online", checkpoint_interval = 10,
-                               keep_last_checkpoint = TRUE, learning_decay = 0.51, learning_offset = 1024,
-                               optimize_doc_concentration = TRUE, seed = NULL, features_col = "features",
-                               topic_distribution_col = "topicDistribution", uid = random_string("lda_"), ...) {
+ml_lda.ml_pipeline <- function(
+    x, formula = NULL, k = 10, max_iter = 20, doc_concentration = NULL, topic_concentration = NULL,
+    subsampling_rate = 0.05, optimizer = "online", checkpoint_interval = 10,
+    keep_last_checkpoint = TRUE, learning_decay = 0.51, learning_offset = 1024,
+    optimize_doc_concentration = TRUE, seed = NULL, features_col = "features",
+    topic_distribution_col = "topicDistribution", uid = random_string("lda_"), ...) {
   stage <- ml_lda.spark_connection(
     x = spark_connection(x),
     formula = formula,
@@ -221,11 +273,12 @@ ml_lda.ml_pipeline <- function(x, formula = NULL, k = 10, max_iter = 20, doc_con
 }
 
 #' @export
-ml_lda.tbl_spark <- function(x, formula = NULL, k = 10, max_iter = 20, doc_concentration = NULL, topic_concentration = NULL,
-                             subsampling_rate = 0.05, optimizer = "online", checkpoint_interval = 10,
-                             keep_last_checkpoint = TRUE, learning_decay = 0.51, learning_offset = 1024,
-                             optimize_doc_concentration = TRUE, seed = NULL, features_col = "features",
-                             topic_distribution_col = "topicDistribution", uid = random_string("lda_"), ...) {
+ml_lda.tbl_spark <- function(
+    x, formula = NULL, k = 10, max_iter = 20, doc_concentration = NULL, topic_concentration = NULL,
+    subsampling_rate = 0.05, optimizer = "online", checkpoint_interval = 10,
+    keep_last_checkpoint = TRUE, learning_decay = 0.51, learning_offset = 1024,
+    optimize_doc_concentration = TRUE, seed = NULL, features_col = "features",
+    topic_distribution_col = "topicDistribution", uid = random_string("lda_"), ...) {
   formula <- ml_standardize_formula(formula)
 
   stage <- ml_lda.spark_connection(
@@ -311,13 +364,14 @@ ml_construct_model_lda <- function(constructor, predictor, formula, dataset, fea
   rlang::exec(constructor, !!!.args)
 }
 
-ml_lda_pipeline <- function(predictor, dataset, formula, features_col,
-                            # regex tokenizer parameters
-                            gaps, min_token_length, pattern, to_lower_case,
-                            # stop words remover parameters
-                            case_sensitive, stop_words,
-                            # count vectorizer parameters
-                            binary, min_df, min_tf, vocab_size) {
+ml_lda_pipeline <- function(
+    predictor, dataset, formula, features_col,
+    # regex tokenizer parameters
+    gaps, min_token_length, pattern, to_lower_case,
+    # stop words remover parameters
+    case_sensitive, stop_words,
+    # count vectorizer parameters
+    binary, min_df, min_tf, vocab_size) {
   sc <- spark_connection(predictor)
 
   # Temporary column names to prevent clashes
