@@ -1,7 +1,8 @@
 new_ml_model_linear_svc <- function(pipeline_model, formula, dataset, label_col,
                                     features_col, predicted_label_col) {
   m <- new_ml_model_classification(
-    pipeline_model, formula, dataset = dataset,
+    pipeline_model, formula,
+    dataset = dataset,
     label_col = label_col, features_col = features_col,
     predicted_label_col = predicted_label_col,
     class = "ml_model_linear_svc"
@@ -13,11 +14,12 @@ new_ml_model_linear_svc <- function(pipeline_model, formula, dataset, label_col,
   coefficients <- model$coefficients
   names(coefficients) <- m$feature_names
 
-  m$coefficients <- if (ml_param(model, "fit_intercept"))
+  m$coefficients <- if (ml_param(model, "fit_intercept")) {
     rlang::set_names(
       c(invoke(jobj, "intercept"), model$coefficients),
       c("(Intercept)", m$feature_names)
     )
+  }
 
   m
 }
