@@ -93,31 +93,20 @@ ml_load <- function(sc, path) {
       spark_normalize_path()
   }
 
-  metadata_folder <- file.path(path, "metadata")
-  metadata_files <- list.files(metadata_folder)
-  part_find <- startsWith(metadata_files, "part-00000")
+  metadata <- try(
+    spark_context(sc) %>%
+      invoke("textFile", file.path(path, "metadata", "part-00*"), 1L) %>%
+      invoke("collect") %>%
+      unlist() %>%
+      jsonlite::fromJSON(),
+    silent = TRUE
+  )
 
-  if(any(part_find)) {
-    part_file <- metadata_files[part_find][[1]]
-    part_path <- file.path(metadata_folder, part_file)
+  if (!inherits(metadata, "try-error")) {
+    class <- metadata$class
+    invoke_static(sc, class, "load", path) %>%
+      ml_call_constructor()
   } else {
-    stop("ML Pipeline metadata file not found (part-00000*)")
+    stop("ML could not be loaded:\n  ", metadata)
   }
-  metadata_table_name <- random_string("ml_load_metadata")
-  class <- spark_read_json(
-    sc = sc,
-    name = metadata_table_name,
-    path = part_path
-  ) %>%
-    dplyr::pull(!!rlang::sym("class"))
-
-  # Drop temp view
-  if (spark_version(sc) > "2.0.0") {
-    spark_session(sc) %>%
-      invoke("catalog") %>%
-      invoke("dropTempView", metadata_table_name)
-  }
-
-  invoke_static(sc, class, "load", path) %>%
-    ml_call_constructor()
 }
