@@ -56,7 +56,7 @@ nest.tbl_spark <- function(.data, ..., .names_sep = NULL, .key = NULL) {
           src_name <- fields[[idx]]
           sprintf(
             "%s, %s",
-            dbplyr::translate_sql_(list(dst_name), con = dbplyr::simulate_dbi()),
+            dbplyr::translate_sql_(list(dst_name), con = dbplyr::simulate_hive()),
             quote_sql_name(src_name)
           )
         }) %>%
