@@ -7,6 +7,11 @@ import scala.Option
 import scala.reflect.ClassTag
 import scala.util.Try
 
+import org.apache.spark.sql.Row
+import org.apache.spark.ml.linalg.{Vector, DenseVector}
+import org.apache.spark.ml.linalg.{Vector => NewVector}
+import org.apache.spark.mllib.linalg.{Vector => OldVector}
+
 object Collectors {
   val ReDecimalType = "(^DecimalType(\\(.*\\)?)$)".r
   val ReVectorType  = "(.*VectorUDT.*)".r
@@ -190,8 +195,13 @@ object Collectors {
     val el = row(idx)
     el match {
       case null => Array.empty
-      case _: Seq[_] => el.asInstanceOf[Seq[Any]].toArray
-      case _ => el.getClass.getDeclaredMethod("toArray").invoke(el).asInstanceOf[Array[_]]
+      case seq: Seq[_] => seq.toArray(ClassTag.Any) // Scala Collections
+      case arrSeq: scala.collection.mutable.ArraySeq[_] => arrSeq.toArray(ClassTag.Any) // ArraySeq
+      case vec: NewVector => vec.toArray // Spark 3.x+ ML Vectors
+      case vec: OldVector => vec.toArray // Legacy MLlib Vectors
+      case array: Array[_] => array // Arrays
+      case _ =>
+        throw new UnsupportedOperationException(s"Cannot convert ${el.getClass} to array")
     }
   }
 
